<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:url="http://www.jclark.com/xt/java/java.net.URLEncoder"
    exclude-result-prefixes="url"
    version="1.0">
    <!-- This is a general set of xsl templates to generate a Google Chart input XML
         content. So far only Pie charts are implemented.
        
         See http://code.google.com/apis/chart/ for more information.
        
         This style sheet was created by Karl Stubsjoen and Kevin Brown from
         RenderX. Feel free to use as you please and of course check with 
         the Google website for their terms of using their services.
    -->
    <!-- This is the Google Chart Server URL -->
    <xsl:param name="chartserver">http://chart.apis.google.com/chart</xsl:param>
    <!-- The type of chart to create (required) -->
    <xsl:param name="type"/>
    <!-- The orientation of the pie chart in radians -->
    <xsl:param name="orientation"/>
    <!-- The chart width and height. Refer to the google specs for this but their 
         recommendation is the the width be at least 2x the height for pie charts -->
    <xsl:param name="width">250</xsl:param>
    <xsl:param name="height">100</xsl:param>
    <!-- A "|" delimted set of colors. If only one color is specified then it is used
         as a base color and all pie slices are colored in varying shades of this color -->
    <xsl:param name="colors"/>
    <!-- The data passed as an object -->
    <xsl:param name="data"/>
    <!-- The data for the inside pie in a concentric pie chart -->
    <xsl:param name="datainside"/>
    <!-- The labels passed as an object -->
    <xsl:param name="labels"/>
    <!-- The labels for the inside pie in a concentric pie chart -->
    <xsl:param name="labelsinside"/>
    <!-- Main Template -->
    <xsl:template name="build.static-pie">
        <xsl:param name="type"/>
        <xsl:param name="orientation"/>
        <xsl:param name="data"/>
        <xsl:param name="datainside"/>
        <xsl:param name="labels"/>
        <xsl:param name="labelsinside"/>
        <xsl:param name="width"/>
        <xsl:param name="height"/>
        <xsl:param name="colors"/>
        <!-- Add Chart Server URL -->
        <xsl:value-of select="$chartserver"/>
        <!-- Add Chart Type -->
        <xsl:text>?cht=</xsl:text>
        <xsl:value-of select="$type"/>
        <!-- Add Orientation -->
        <xsl:if test="$orientation">
            <xsl:text>&amp;chp=</xsl:text>
            <xsl:value-of select="$orientation"/>
        </xsl:if>
        <!-- Add Data -->
        <xsl:text>&amp;chd=t:</xsl:text>
        <xsl:if test="$datainside">
            <xsl:for-each select="$datainside">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:value-of select="."/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="."/>
                        <xsl:text>,</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:text>|</xsl:text>
        </xsl:if>
        <xsl:if test="$data">
            <xsl:for-each select="$data">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:value-of select="."/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="."/>
                        <xsl:text>,</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:if>
        <!-- Add Colors -->
        <xsl:if test="$colors">
            <xsl:text>&amp;chco=</xsl:text>
            <xsl:value-of select="$colors"/>
        </xsl:if>
        <!-- Add Chart Size -->
        <xsl:text>&amp;chs=</xsl:text>
        <xsl:value-of select="$width"/>
        <xsl:text>x</xsl:text>
        <xsl:value-of select="$height"/>
        <!-- Add Labels -->
        <xsl:text>&amp;chl=</xsl:text>
        <xsl:if test="$labelsinside">
            <xsl:for-each select="$labelsinside">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:value-of select="url:encode(.)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="url:encode(.)"/>
                        <xsl:text>|</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:text>|</xsl:text>
        </xsl:if>
        <xsl:if test="$labels">
            <xsl:for-each select="$labels">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:value-of select="url:encode(.)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="url:encode(.)"/>
                        <xsl:text>|</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="build.static-pin_letter">
        <!-- http://www.google.com/chart?chst=d_map_pin_letter&chld=A|FF0000|000000 -->
        <!-- format is:
             letter
             pin-color
             text-color -->
        <xsl:param name="letter" select="A"/>
        <xsl:param name="pin-color" select="FF0000"/>
        <xsl:param name="text-color" select="000000"/>
        <!-- Add Chart Server URL -->
        <xsl:value-of select="$chartserver"/>
        <!-- Add Chart Type -->
        <xsl:text>?chst=d_map_pin_letter</xsl:text>
        <!-- Start the parameters -->
        <xsl:text>&amp;chld=</xsl:text>
        <!-- Add the character -->
        <xsl:value-of select="$letter"/>
        <!-- Add the pin color -->
        <xsl:text>|</xsl:text>
        <xsl:value-of select="$pin-color"/>
        <!-- Add the text color -->
        <xsl:text>|</xsl:text>
        <xsl:value-of select="$text-color"/>
    </xsl:template>
    
    <xsl:template name="build.static-sticky">
        <!-- http://www.google.com/chart?chst=d_weather&chld=sticky_y|sunny|Barcelona|max+25%C2%B0|min+15%C2%B0 -->
        <!-- http://chart.apis.google.com/chart?chst=bubble&amp;chld=Sticky+Note|First+line+of+text|Second+line+of+text -->
        <xsl:param name="notetype" select="sticky_y"/>
        <xsl:param name="notesize" select="1"/>
        <xsl:param name="text-color" select="FFFFF"/>
        <xsl:param name="text-align" select="l"/>
        <xsl:param name="title" select="Title"/>
        <xsl:param name="line1" select="line1"/>
        <xsl:param name="line2" select="line2"/>
        <!-- Add Chart Server URL -->
        <xsl:value-of select="$chartserver"/>
        <!-- Use Note template with Title -->
        <xsl:text>?chst=d_fnote_title</xsl:text>
        <xsl:text>&amp;chld=</xsl:text>
        <!-- Add Note Type -->
        <xsl:value-of select="$notetype"/>
        <xsl:text>|</xsl:text>
        <!-- Add Note Size -->
        <xsl:value-of select="$notesize"/>
        <xsl:text>|</xsl:text>
        <!-- Add text-color -->
        <xsl:value-of select="$text-color"/>
        <xsl:text>|</xsl:text>
        <!-- Add text alignment -->
        <xsl:value-of select="$text-align"/>
        <xsl:text>|</xsl:text>
        <!-- Add the three lines, first is title -->
        <xsl:value-of select="url:encode($title)"/>
        <xsl:if test="$line1">
            <xsl:text>|</xsl:text>
            <xsl:value-of select="url:encode($line1)"/>
        </xsl:if>
        <xsl:if test="$line2">
            <xsl:text>|</xsl:text>
            <xsl:value-of select="url:encode($line2)"/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="build.static-outlinetext">
        <xsl:param name="text-color"/>
        <xsl:param name="font-size"/>
        <xsl:param name="text-align"/>
        <xsl:param name="outline-color"/>
        <xsl:param name="font-style" select="_"/>
        <xsl:param name="line"/>
        <!-- Add Chart Server URL -->
        <xsl:value-of select="$chartserver"/>
        <!-- Use Outline Text Mode -->
        <xsl:text>?chst=d_text_outline</xsl:text>
        <xsl:text>&amp;chld=</xsl:text>
        <!-- Add text-color -->
        <xsl:value-of select="$text-color"/>
        <xsl:text>|</xsl:text>
        <!-- Add Font Size -->
        <xsl:value-of select="$font-size"/>
        <xsl:text>|</xsl:text>
        <!-- Add text alignment -->
        <xsl:value-of select="$text-align"/>
        <xsl:text>|</xsl:text>
        <!-- Add Outline Color -->
        <xsl:value-of select="$outline-color"/>
        <xsl:text>|</xsl:text>
        <!-- Add Font Style -->
        <xsl:value-of select="$font-style"/>
        <xsl:text>|</xsl:text>
        <xsl:if test="$line">
            <xsl:for-each select="$line">
                <xsl:choose>
                    <xsl:when test="position()=last()">
                        <xsl:value-of select="url:encode(.)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="url:encode(.)"/>
                        <xsl:text>|</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <xsl:text>|</xsl:text>
        </xsl:if>
    </xsl:template>

    
</xsl:stylesheet>
